@@ -200,7 +200,7 @@ class PreviewUtils:
         return nestor_values
 
     def get_spec_values(self, sections: collections.abc.Iterable = ("default",), stage="runtime"):
-        cfg_file_name = ".nestor-cgf.yml"
+        cfg_file_name = ".nestor-cfg.yml"
         preview_confs_path = os.path.join(os.path.dirname(__file__), "default-preview-nestor-cfg.yml")
         nestor_cfg_path = os.path.join(self.env_config.CI_PROJECT_DIR, cfg_file_name)
 
@@ -341,6 +341,7 @@ class PreviewUpScript(ScriptNestor):
         values = self.preview_utils.get_spec_values(
             sections=["default", "preview", self.config.CI_COMMIT_REF_NAME], stage="runtime"
         )
+        values.add(self.preview_utils._create_all_spec_sources(self.config.CI_PROJECT_PATH))
         values = self.enable_s3_spec(values)
         self.log_spec(values)
         self.edit_with_values(values)
