@@ -113,7 +113,7 @@ class NestorDescSet:
         print("Parsing section [%s] of %s" % (section, path_nestor_cfg))
         for key, value in Utils.flat_dico((), data.get(section, {})):
             try:
-                nestor_values.add(NestorOpt(".".join(key), Utils.quote_if_needed(value)))
+                nestor_values.add(NestorOpt(".".join(key), value))
             except TypeError as e:
                 print(key, value)
                 print(e, flush=True)
@@ -287,7 +287,6 @@ class NestorCommand:
 
 class NestorInstance:
     def __init__(self, name, verbose=False):
-        self.progressive_spec = None
         self.name = name
         self.verbose = verbose
         self.filestore = NestorFileStoreCommand(self)
@@ -305,19 +304,6 @@ class NestorInstance:
             raise ValueError("Version can't be found")
         return int(float(value))
 
-    def start_progressive_spec(self, odoo_version: Union[int, float, str] = None):
-        assert odoo_version or self.exist(), "Please create config first"
-        self.progressive_spec = NestorDescSet()
-        self.progressive_spec.add(NestorOpt("version", str(float(odoo_version))))
-
-    def commit_progressive_spec(self):
-        assert self.progressive_spec, "Please use start_progressive_edit first"
-        if not self.exist():
-            self.create(str(self.version), self.progressive_spec)
-        else:
-            self.edit(self.progressive_spec)
-        self.progressive_spec = None
-
     def save_spec(self, values: NestorDescSet, path_dir: str):
         full_path = path_dir
         if os.path.splitext(path_dir)[1] != "spec":
@@ -370,10 +356,7 @@ class NestorInstance:
         return [NestorInstance(s.strip()) for s in r.splitlines()[1:]]
 
     def edit(self, values_set: NestorDescSet = None) -> int:
-        if self.progressive_spec:
-            self.progressive_spec.add(values_set)
-        else:
-            self._edit(values_set)
+        return self._edit(values_set)
 
     def _edit(self, values_set: NestorDescSet = None) -> int:
         self._clear_cache()
@@ -383,10 +366,9 @@ class NestorInstance:
         if values_set:
             opt.append("--set")
             opt.append('"%s"' % values_set.to_str())
-        # return self._call("edit", *opt)
+        return self._call("edit", *opt)
 
     def filestore_s3_dump(self, s3_secret: str = None, bucket: str = None, verbose: bool = False):
-        # nestor filestore dump pep s3 pep --progress --bucket=pep --s3=s3-ndp-migration
         self._call(["filestore", "dump"], "s3", ".", "--progress", "--bucket", bucket or self.name, "--s3", s3_secret)
 
     def db_restore_from_s3(
